@@ -220,25 +220,11 @@ class GtkUI(glchess.ui.UI):
         self._gui = loadGladeFile('glchess.glade')
         self._gui.signal_autoconnect(self)
         
+        self.mainWindow = self._gui.get_widget('glchess_app')
+        
         # Workaround as Glade 2 always overrides the system style for toolbars
         self.__getWidget('toolbar').unset_style()
         
-        # Create mappings between the promotion radio buttons and the promotion types
-        self.__promotionTypeByRadio = {}
-        self.__promotionRadioByType = {}
-        for piece in ['queen', 'knight', 'rook', 'bishop']:
-            widget = self.__getWidget('promotion_%s_radio' % piece)
-            self.__promotionTypeByRadio[widget] = piece
-            self.__promotionRadioByType[piece] = widget
-
-        # Create mappings between the board view radio buttons and the config names
-        self.__boardViewRadioByType = {}
-        self.__boardViewTypeByRadio = {}
-        for name in ['white', 'black', 'human', 'current']:
-            widget = self.__getWidget('menu_side_%s' % name)
-            self.__boardViewTypeByRadio[widget] = name
-            self.__boardViewRadioByType[name] = widget
-
         # Create the model for the player types
         self.__playerModel = gtk.ListStore(str, str, str)
         iconTheme = gtk.icon_theme_get_default()
@@ -246,6 +232,9 @@ class GtkUI(glchess.ui.UI):
         self.__playerModel.set(iter, 0, '', 1, 'stock_person', 2, _('Human'))
         
         self.__logWindow = log.LogWindow(self._gui.get_widget('log_notebook'))
+        
+        # Make preferences dialog
+        self.preferences = dialogs.GtkPreferencesDialog(self)
 
         # Balance space on each side of the history combo
         group = gtk.SizeGroup(gtk.SIZE_GROUP_BOTH)
@@ -373,7 +362,7 @@ class GtkUI(glchess.ui.UI):
         else:
             # Translators: This is the window title when not playing a game
             title = _('Chess')            
-        self._gui.get_widget('glchess_app').set_title(title)
+        self.mainWindow.set_title(title)
 
     def addLogWindow(self, title, executable, description):
         """
@@ -419,7 +408,7 @@ class GtkUI(glchess.ui.UI):
                 self.__applyConfig(name, value)
         self.__resize()
         
-        self._gui.get_widget('glchess_app').show()
+        self.mainWindow.show()
 
         # Apply the fullscreen flag after the window has been shown otherwise
         # gtk.Window.unfullscreen() stops working if the window is set to fullscreen
@@ -501,7 +490,7 @@ class GtkUI(glchess.ui.UI):
     def __updateAttention(self):
         """
         """
-        widget = self._gui.get_widget('glchess_app')
+        widget = self.mainWindow
         widget.set_urgency_hint(self.__attentionCounter != 0 and not widget.is_active())
         
     def _on_focus_changed(self, widget, event):
@@ -529,7 +518,7 @@ class GtkUI(glchess.ui.UI):
         except glchess.config.Error:
             return
         
-        self._gui.get_widget('glchess_app').resize(width, height)
+        self.mainWindow.resize(width, height)
 
     def __applyConfig(self, name, value):
         """
@@ -541,12 +530,9 @@ class GtkUI(glchess.ui.UI):
         # Show/hide the toolbar
         if name == 'show_toolbar':
             toolbar = self.__getWidget('toolbar')
-            menu = self.__getWidget('menu_view_toolbar')
             if value is True:
-                menu.set_active(True)
                 toolbar.show()
             else:
-                menu.set_active(False)
                 toolbar.hide()
                 
         elif name == 'enable_networking':
@@ -562,17 +548,14 @@ class GtkUI(glchess.ui.UI):
         # Show/hide the history
         elif name == 'show_history':
             box = self.__getWidget('navigation_box')
-            menu = self.__getWidget('menu_view_history')
             if value is True:
-                menu.set_active(True)
                 box.show()
             else:
-                menu.set_active(False)
                 box.hide()
                 
         # Maximised mode
         elif name == 'maximised':
-            window = self._gui.get_widget('glchess_app')
+            window = self.mainWindow
             if value is True:
                 window.maximize()
             else:
@@ -580,7 +563,7 @@ class GtkUI(glchess.ui.UI):
 
         # Fullscreen mode
         elif name == 'fullscreen':
-            window = self._gui.get_widget('glchess_app')
+            window = self.mainWindow
             if value is True:
                 window.fullscreen()
             else:
@@ -608,40 +591,23 @@ Please contact your system administrator to resolve these problems, until then y
             self.view.viewWidget.setRenderGL(self.__renderGL)
                 
         elif name == 'show_comments':
-            menuItem = self.__getWidget('menu_view_comment')
-            menuItem.set_active(value)
             self.view.setShowComments(value)
 
         elif name == 'show_move_hints':
-            menuItem = self.__getWidget('menu_view_move_hints')
-            menuItem.set_active(value)
             self.view.feedback.showMoveHints(value)
 
         elif name == 'show_numbering':
-            menuItem = self.__getWidget('menu_view_numbering')
-            menuItem.set_active(value)
             self.view.feedback.showBoardNumbering(value)
 
         elif name == 'move_format':
-            self._gui.get_widget('menu_movef_%s' % value).set_active(True)
             self.view.setMoveFormat(value)
                 
         elif name == 'promotion_type':
-            try:
-                radio = self.__promotionRadioByType[value]
-            except KeyError:
-                glchess.config.default('promotion_type')
-            else:
-                radio.set_active(True)
-                
+            pass
+    
         elif name == 'board_view':
-            try:
-                radio = self.__boardViewRadioByType[value]
-            except KeyError:
-                glchess.config.default('board_view')
-            else:
-                radio.set_active(True)
-                
+            pass
+
         else:
             assert(False), 'Unknown config item: %s' % name
 
@@ -758,7 +724,7 @@ Please contact your system administrator to resolve these problems, until then y
         """Gtk+ callback"""
         window = self._gui.get_widget('log_window')
         if widget.get_active():
-            window.show()
+            window.present()
         else:
             window.hide()
 
@@ -873,8 +839,8 @@ Please contact your system administrator to resolve these problems, until then y
         self.__getWidget('navigation_box').set_sensitive(enable)
         
         enable = enable and self.view.gameResult is None
-        for widget in ('menu_resign', 'resign_button', 'menu_claim_draw'):
-            self.__getWidget(widget).set_sensitive(enable)
+        '''FIXME! for widget in ('menu_resign', 'resign_button', 'menu_claim_draw'):
+            self.__getWidget(widget).set_sensitive(enable)'''
 
     def _on_new_game_button_clicked(self, widget):
         """Gtk+ callback"""
@@ -908,6 +874,10 @@ Please contact your system administrator to resolve these problems, until then y
         """Gtk+ callback"""
         self.view.feedback.claimDraw()
 
+    def _on_preferences_clicked(self, widget):
+        """Gtk+ callback"""
+        self.preferences.setVisible(True)
+
     def _on_help_clicked(self, widget):
         """Gtk+ callback"""
         try:
@@ -942,6 +912,7 @@ Please contact your system administrator to resolve these problems, until then y
             return
         
         dialog = self.__aboutDialog = gtk.AboutDialog()
+        dialog.set_transient_for(self.mainWindow)
         dialog.set_name(APPNAME)
         dialog.set_version(VERSION)
         dialog.set_copyright(COPYRIGHT)
