@@ -9,11 +9,11 @@ if sys.modules["gnome_sudoku"].installed_mode:
     GLADE_DIR = os.path.join(APP_DATA_DIR,'gnome-sudoku')
     BASE_DIR = os.path.join(APP_DATA_DIR,'gnome-sudoku')
 else:
-    APP_DATA_DIR = os.path.join('/home/thomas/svn/gnome-games', 'gnome-sudoku', 'data') 
-    IMAGE_DIR = os.path.join('/home/thomas/svn/gnome-games', 'gnome-sudoku', 'images')
+    APP_DATA_DIR = os.path.join('/home/jclinton/development/svn/GNOME_GAMES_2_21', 'gnome-sudoku', 'data') 
+    IMAGE_DIR = os.path.join('/home/jclinton/development/svn/GNOME_GAMES_2_21', 'gnome-sudoku', 'images')
     LOCALEDIR = os.path.join(APP_DATA_DIR, 'locale')
-    GLADE_DIR = os.path.join('/home/thomas/svn/gnome-games', 'gnome-sudoku', 'glade')
-    BASE_DIR = os.path.join('/home/thomas/svn/gnome-games', 'gnome-sudoku', 'data') 
+    GLADE_DIR = os.path.join('/home/jclinton/development/svn/GNOME_GAMES_2_21', 'gnome-sudoku', 'glade')
+    BASE_DIR = os.path.join('/home/jclinton/development/svn/GNOME_GAMES_2_21', 'gnome-sudoku', 'data') 
 
 DOMAIN = 'gnome-games'
 gettext.bindtextdomain(DOMAIN, LOCALEDIR)
@@ -23,7 +23,7 @@ import gtk.glade
 gtk.glade.bindtextdomain (DOMAIN, LOCALEDIR)
 gtk.glade.textdomain (DOMAIN)
 
-VERSION = "2.21.5"
+VERSION = "2.21.90"
 APPNAME = _("GNOME Sudoku")
 APPNAME_SHORT = _("Sudoku")
 COPYRIGHT = 'Copyright \xc2\xa9 2005-2007, Thomas M. Hinkle'
